# Artifact Management Tool User Interface
[![PyPI version](https://img.shields.io/pypi/v/amtui.svg)](https://pypi.python.org/pypi/amtui/)
[![PyPI pyversions](https://img.shields.io/pypi/pyversions/amtui.svg)](https://pypi.python.org/pypi/amtui/)
[![Travis](https://api.travis-ci.org/bellockk/amtui.svg?branch=master)](https://travis-ci.org/bellockk/amtui/)
[![CodeCov](https://codecov.io/gh/bellockk/amtui/branch/master/graph/badge.svg)](https://codecov.io/gh/bellockk/amtui)
[![Documentation Status](https://readthedocs.org/projects/amtui/badge/?version=latest)](http://amtui.readthedocs.io/?badge=latest)
[![MIT license](https://img.shields.io/badge/License-MIT-blue.svg)](https://lbesson.mit-license.org/)




Statement of Purpose
--------------------

A user interface to the Artifact Management Tool


* Free software: MIT license
* Documentation: https://amtui.readthedocs.io.


## Features
--------

* TODO

## Credits

This package was created with [Cookiecutter](https://github.com/audreyr/cookiecutter) and the [audreyr/cookiecutter-pypackage](https://github.com/audreyr/cookiecutter-pypackage) project template.
